@@ -1,9 +1,14 @@
 from django.db.models import Count
-from django_readers import projectors, qs
+from django_readers import producers, projectors, qs
+
+
+def producer_to_projector(name, pair):
+    prepare, produce = pair
+    return prepare, projectors.producer_to_projector(name, produce)
 
 
 def field(name, *, transform_value=None, transform_value_if_none=False):
-    return qs.include_fields(name), projectors.attr(
+    return qs.include_fields(name), producers.attr(
         name,
         transform_value=transform_value,
         transform_value_if_none=transform_value_if_none,
@@ -19,11 +24,6 @@ def combine(*pairs):
     return qs.pipe(*prepare_fns), projectors.combine(*project_fns)
 
 
-def alias(alias_or_aliases, pair):
-    prepare, project = pair
-    return prepare, projectors.alias(alias_or_aliases, project)
-
-
 def prepare_only(prepare):
     return prepare, projectors.noop
 
@@ -35,19 +35,16 @@ def project_only(project):
 def field_display(name):
     """
     Works with Django's get_FOO_display mechanism for fields with choices set. Given
-    the name of a field, calls get_<name>_display, and returns a projector that puts
-    the returned value under the key <name>_display.
+    the name of a field, returns a producer that calls get_<name>_display.
     """
-    return qs.include_fields(name), projectors.alias(
-        f"{name}_display", projectors.method(f"get_{name}_display")
-    )
+    return qs.include_fields(name), producers.method(f"get_{name}_display")
 
 
 def count(name, distinct=True):
     attr_name = f"{name}_count"
     return (
         qs.annotate(**{attr_name: Count(name, distinct=distinct)}),
-        projectors.attr(attr_name),
+        producers.attr(attr_name),
     )
 
 
@@ -55,9 +52,7 @@ def has(name, distinct=True):
     attr_name = f"{name}_count"
     return (
         qs.annotate(**{attr_name: Count(name, distinct=distinct)}),
-        projectors.alias(
-            f"has_{name}", projectors.attr(attr_name, transform_value=bool)
-        ),
+        producers.attr(attr_name, transform_value=bool),
     )
 
 
@@ -75,7 +70,7 @@ def order_by(*args, **kwargs):
 
 """
 Below are pair functions which return the various queryset functions that prefetch
-relationships of various types, and then project those related objects.
+relationships of various types, and then produce those related objects.
 
 There are functions for forward, reverse or many-to-many relationships, and then
 a `relationship` function which selects the correct one by introspecting the
@@ -89,7 +84,7 @@ def forward_relationship(name, related_queryset, relationship_pair, to_attr=None
     prepare = qs.prefetch_forward_relationship(
         name, related_queryset, prepare_related_queryset, to_attr
     )
-    return prepare, projectors.relationship(to_attr or name, project_relationship)
+    return prepare, producers.relationship(to_attr or name, project_relationship)
 
 
 def reverse_relationship(
@@ -99,7 +94,7 @@ def reverse_relationship(
     prepare = qs.prefetch_reverse_relationship(
         name, related_name, related_queryset, prepare_related_queryset, to_attr
     )
-    return prepare, projectors.relationship(to_attr or name, project_relationship)
+    return prepare, producers.relationship(to_attr or name, project_relationship)
 
 
 def many_to_many_relationship(name, related_queryset, relationship_pair, to_attr=None):
@@ -107,17 +102,17 @@ def many_to_many_relationship(name, related_queryset, relationship_pair, to_attr
     prepare = qs.prefetch_many_to_many_relationship(
         name, related_queryset, prepare_related_queryset, to_attr
     )
-    return prepare, projectors.relationship(to_attr or name, project_relationship)
+    return prepare, producers.relationship(to_attr or name, project_relationship)
 
 
 def relationship(name, relationship_pair, to_attr=None):
     prepare_related_queryset, project_relationship = relationship_pair
     prepare = qs.auto_prefetch_relationship(name, prepare_related_queryset, to_attr)
-    return prepare, projectors.relationship(to_attr or name, project_relationship)
+    return prepare, producers.relationship(to_attr or name, project_relationship)
 
 
 def pk_list(name, to_attr=None):
     return (
         qs.auto_prefetch_relationship(name, qs.include_fields("pk"), to_attr=to_attr),
-        projectors.pk_list(to_attr or name),
+        producers.pk_list(to_attr or name),
     )
